@@ -187,14 +187,18 @@ END { if ($ENV{PAR_CLEAN}) {
         # directory does not get reused while it is being deleted, try to
         # rename it to a name that is related to the temporary script file.
 
-        my $tmpname = (File::Spec->splitpath($tmp->filename))[2]; # filename
-        $tmpname =~ s/\.[^.]*$/.dir/;
-        my $newDir = File::Spec->catpath(
-            (File::Spec->splitpath($par_temp))[0..1], $tmpname);
-        if (rename $par_temp, $newDir) {
-            outs("Renamed $par_temp to $newDir");
-            $par_temp = $newDir;
-        }
+# FIXME: This breaks threaded applications. A fix is in the works, but may
+#        still take a while. The fix would be to make sure that this is only
+#        run in the LAST REMAINING thread.
+        
+#        my $tmpname = (File::Spec->splitpath($tmp->filename))[2]; # filename
+#        $tmpname =~ s/\.[^.]*$/.dir/;
+#        my $newDir = File::Spec->catpath(
+#            (File::Spec->splitpath($par_temp))[0..1], $tmpname);
+#        if (rename $par_temp, $newDir) {
+#            outs("Renamed $par_temp to $newDir");
+#            $par_temp = $newDir;
+#        }
 
         if ($^O =~ m/win32/i) {
             print $tmp "
@@ -413,11 +417,13 @@ if (!$start_pos or ($ARGV[0] eq '--par-options' && shift)) {
         s   sign_par
         v   verify_par
     );
+
+    my @add_to_inc;
     while (@ARGV) {
         $ARGV[0] =~ /^-([AIMOBLbqpiusTv])(.*)/ or last;
 
         if ($1 eq 'I') {
-            unshift @INC, $2;
+            push @add_to_inc, $2;
         }
         elsif ($1 eq 'M') {
             eval "use $2";
@@ -455,6 +461,8 @@ if (!$start_pos or ($ARGV[0] eq '--par-options' && shift)) {
             exit;
         }
     }
+
+    unshift @INC, @add_to_inc;
 }
 
 # XXX -- add --par-debug support!
@@ -696,8 +704,12 @@ if ($out) {
             }x;
             my $extract_name = $1;
             my $dest_name = File::Spec->catfile($ENV{PAR_TEMP}, $extract_name);
-            $member->extractToFileNamed($dest_name);
-            outs(qq(Extracting "$member_name" to "$dest_name"));
+            if (-f $dest_name && -s _ == $member->uncompressedSize()) {
+                outs(qq(Skipping "$member_name" since it already exists at "$dest_name"));
+            } else {
+                $member->extractToFileNamed($dest_name);
+                outs(qq(Extracting "$member_name" to "$dest_name"));
+            }
         }
     }
     # }}}
